@@ -5,8 +5,13 @@ from nsj_rest_lib.controller.controller_util import DEFAULT_RESP_HEADERS
 from nsj_rest_lib.controller.route_base import RouteBase
 from nsj_rest_lib.dto.dto_base import DTOBase
 from nsj_rest_lib.entity.entity_base import EntityBase
-from nsj_rest_lib.exception import DTOConfigException, MissingParameterException, NotFoundException
+from nsj_rest_lib.exception import (
+    DTOConfigException,
+    MissingParameterException,
+    NotFoundException,
+)
 from nsj_rest_lib.injector_factory_base import NsjInjectorFactoryBase
+from nsj_rest_lib.settings import get_logger
 
 from nsj_gcf_utils.json_util import json_dumps
 from nsj_gcf_utils.pagination_util import PaginationException
@@ -23,8 +28,6 @@ class GetRoute(RouteBase):
         injector_factory: NsjInjectorFactoryBase = NsjInjectorFactoryBase,
         service_name: str = None,
         handle_exception: Callable = None,
-        require_tenant: bool = True,
-        require_grupo_emprearial: bool = True
     ):
         super().__init__(
             url=url,
@@ -35,8 +38,6 @@ class GetRoute(RouteBase):
             injector_factory=injector_factory,
             service_name=service_name,
             handle_exception=handle_exception,
-            require_tenant=require_tenant,
-            require_grupo_emprearial=require_grupo_emprearial,
         )
 
     def handle_request(self, id):
@@ -50,36 +51,32 @@ class GetRoute(RouteBase):
                 args = request.args
 
                 # Tratando dos fields
-                fields = args.get('fields')
+                fields = args.get("fields")
                 fields = self._parse_fields(fields)
 
-                # Tratando do tenant e do grupo_empresarial
-                # TODO Refatorar para exibir os dois erros ao mesmo tempo
-                tenant = args.get('tenant')
-                grupo_empresarial = args.get('grupo_empresarial')
+                partition_fields = {}
+                # Tratando campos de particionamento
+                for field in self._dto_class.partition_fields:
+                    value = args.get(field)
+                    if value is None:
+                        raise MissingParameterException(field)
 
-                if self._require_tenant:
-                    if tenant is None:
-                        raise MissingParameterException('tenant')
+                    partition_fields[field] = value
 
-                    if not ('tenant' in self._dto_class.fields_map):
-                        raise DTOConfigException(
-                            f"Missing 'tenant' field declaration on DTOClass: {self._dto_class}")
-
-                if self._require_grupo_emprearial:
-                    if grupo_empresarial is None:
-                        raise MissingParameterException('grupo_empresarial')
-
-                    if not ('grupo_empresarial' in self._dto_class.fields_map):
-                        raise DTOConfigException(
-                            f"Missing 'grupo_empresarial' field declaration on DTOClass: {self._dto_class}")
+                # Tratando do filtro de conjunto
+                if self._dto_class.conjunto_field is not None:
+                    value = args.get(self._dto_class.conjunto_field)
+                    if value is None:
+                        raise MissingParameterException(field)
+                    elif value is not None:
+                        partition_fields[self._dto_class.conjunto_field] = value
 
                 # Construindo os objetos
                 service = self._get_service(factory)
 
                 # Chamando o service (método get)
                 # TODO Rever parametro order_fields abaixo
-                data = service.get(id, grupo_empresarial, tenant, fields)
+                data = service.get(id, partition_fields, fields)
 
                 # Convertendo para o formato de dicionário (permitindo omitir campos do DTO)
                 dict_data = data.convert_to_dict(fields)
@@ -87,22 +84,30 @@ class GetRoute(RouteBase):
                 # Retornando a resposta da requuisição
                 return (json_dumps(dict_data), 200, {**DEFAULT_RESP_HEADERS})
             except MissingParameterException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 400, {**DEFAULT_RESP_HEADERS})
             except PaginationException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 400, {**DEFAULT_RESP_HEADERS})
             except NotFoundException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 404, {**DEFAULT_RESP_HEADERS})
             except Exception as e:
+                get_logger().exception(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
-                    return (format_json_error(f'Erro desconhecido: {e}'), 500, {**DEFAULT_RESP_HEADERS})
+                    return (
+                        format_json_error(f"Erro desconhecido: {e}"),
+                        500,
+                        {**DEFAULT_RESP_HEADERS},
+                    )
