@@ -5,8 +5,13 @@ from nsj_rest_lib.controller.controller_util import DEFAULT_RESP_HEADERS
 from nsj_rest_lib.controller.route_base import RouteBase
 from nsj_rest_lib.dto.dto_base import DTOBase
 from nsj_rest_lib.entity.entity_base import EntityBase
-from nsj_rest_lib.exception import DTOConfigException, MissingParameterException, NotFoundException
+from nsj_rest_lib.exception import (
+    DTOConfigException,
+    MissingParameterException,
+    NotFoundException,
+)
 from nsj_rest_lib.injector_factory_base import NsjInjectorFactoryBase
+from nsj_rest_lib.settings import get_logger
 
 from nsj_gcf_utils.json_util import json_dumps, json_loads, JsonLoadException
 from nsj_gcf_utils.rest_error_util import format_json_error
@@ -23,8 +28,7 @@ class PutRoute(RouteBase):
         injector_factory: NsjInjectorFactoryBase = NsjInjectorFactoryBase,
         service_name: str = None,
         handle_exception: Callable = None,
-        require_tenant: bool = True,
-        require_grupo_emprearial: bool = True
+        custom_after_update: Callable = None,
     ):
         super().__init__(
             url=url,
@@ -35,9 +39,8 @@ class PutRoute(RouteBase):
             injector_factory=injector_factory,
             service_name=service_name,
             handle_exception=handle_exception,
-            require_tenant=require_tenant,
-            require_grupo_emprearial=require_grupo_emprearial,
         )
+        self.custom_after_update = custom_after_update
 
     def handle_request(self, id):
         """
@@ -47,46 +50,31 @@ class PutRoute(RouteBase):
         with self._injector_factory() as factory:
             try:
                 # Recuperando os dados do corpo da rquisição
-                data = request.get_data(as_text=True)
-                data = json_loads(data)
-
-                # Tratando do tenant e do grupo_empresarial
-                tenant = data.get('tenant')
-                grupo_empresarial = data.get('grupo_empresarial')
-
-                if self._require_tenant:
-                    if tenant is None:
-                        raise MissingParameterException('tenant')
-
-                    if not ('tenant' in self._dto_class.fields_map):
-                        raise DTOConfigException(
-                            f"Missing 'tenant' field declaration on DTOClass: {self._dto_class}")
-
-                if self._require_grupo_emprearial:
-                    if grupo_empresarial is None:
-                        raise MissingParameterException('grupo_empresarial')
-
-                    if not ('grupo_empresarial' in self._dto_class.fields_map):
-                        raise DTOConfigException(
-                            f"Missing 'grupo_empresarial' field declaration on DTOClass: {self._dto_class}")
-
-                # Montando os filtros de particao de dados
-                patition_filters = {}
-
-                if tenant is not None:
-                    patition_filters['tenant'] = tenant
-
-                if grupo_empresarial is not None:
-                    patition_filters['grupo_empresarial'] = grupo_empresarial
+                data = request.json
 
                 # Convertendo os dados para o DTO
-                data = self._dto_class(**data)
+                data = self._dto_class(**data, generate_default_pk_value=False)
+
+                # Montando os filtros de particao de dados
+                partition_filters = {}
+
+                for field in data.partition_fields:
+                    value = getattr(data, field)
+                    if value is None:
+                        raise MissingParameterException(field)
+                    elif value is not None:
+                        partition_filters[field] = value
 
                 # Construindo os objetos
                 service = self._get_service(factory)
 
                 # Chamando o service (método insert)
-                data = service.update(data, id, patition_filters)
+                data = service.update(
+                    dto=data,
+                    id=id,
+                    aditional_filters=partition_filters,
+                    custom_after_update=self.custom_after_update,
+                )
 
                 if data is not None:
                     # Convertendo para o formato de dicionário
@@ -96,29 +84,38 @@ class PutRoute(RouteBase):
                     return (json_dumps(dict_data), 200, {**DEFAULT_RESP_HEADERS})
                 else:
                     # Retornando a resposta da requuisição
-                    return ('', 204, {**DEFAULT_RESP_HEADERS})
+                    return ("", 204, {**DEFAULT_RESP_HEADERS})
             except JsonLoadException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 400, {**DEFAULT_RESP_HEADERS})
             except MissingParameterException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 400, {**DEFAULT_RESP_HEADERS})
             except ValueError as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 400, {**DEFAULT_RESP_HEADERS})
             except NotFoundException as e:
+                get_logger().warning(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
                     return (format_json_error(e), 404, {**DEFAULT_RESP_HEADERS})
             except Exception as e:
+                get_logger().exception(e)
                 if self._handle_exception is not None:
                     return self._handle_exception(e)
                 else:
-                    return (format_json_error(f'Erro desconhecido: {e}'), 500, {**DEFAULT_RESP_HEADERS})
+                    return (
+                        format_json_error(f"Erro desconhecido: {e}"),
+                        500,
+                        {**DEFAULT_RESP_HEADERS},
+                    )
