@@ -1,4 +1,6 @@
 from typing import Any, Dict
+
+from nsj_rest_lib.descriptor.conjunto_type import ConjuntoType
 from nsj_rest_lib.descriptor.dto_field import DTOField
 from nsj_rest_lib.descriptor.dto_list_field import DTOListField
 
@@ -6,11 +8,22 @@ from nsj_rest_lib.descriptor.dto_list_field import DTOListField
 class DTO:
     def __init__(
         self,
-        fixed_filters: Dict[str, Any] = None
+        fixed_filters: Dict[str, Any] = None,
+        conjunto_type: ConjuntoType = None,
+        conjunto_field: str = None,
     ) -> None:
         super().__init__()
 
         self._fixed_filters = fixed_filters
+        self._conjunto_type = conjunto_type
+        self._conjunto_field = conjunto_field
+
+        if (self._conjunto_type is None and self._conjunto_field is not None) or (
+            self._conjunto_type is not None and self._conjunto_field is None
+        ):
+            raise Exception(
+                "Os parâmetros conjunto_type e conjunto_field devem ser preenchidos juntos (se um for não nulo, ambos devem ser preenchidos)."
+            )
 
     def __call__(self, cls: object):
         """
@@ -18,33 +31,40 @@ class DTO:
         """
 
         # Creating resume_fields in cls, if needed
-        self._check_class_attribute(cls, 'resume_fields', set())
+        self._check_class_attribute(cls, "resume_fields", set())
 
         # Creating fields_map in cls, if needed
-        self._check_class_attribute(cls, 'fields_map', {})
+        self._check_class_attribute(cls, "fields_map", {})
 
         # Creating list_fields_map in cls, if needed
-        self._check_class_attribute(cls, 'list_fields_map', {})
+        self._check_class_attribute(cls, "list_fields_map", {})
 
         # Creating field_filters_map in cls, if needed
-        self._check_class_attribute(cls, 'field_filters_map', {})
+        self._check_class_attribute(cls, "field_filters_map", {})
 
         # Creating pk_field in cls, if needed
         # TODO Refatorar para suportar PKs compostas
-        self._check_class_attribute(cls, 'pk_field', None)
+        self._check_class_attribute(cls, "pk_field", None)
 
         # Criando a propriedade "partition_fields" na classe "cls", se necessário
-        self._check_class_attribute(cls, 'partition_fields', set())
+        self._check_class_attribute(cls, "partition_fields", set())
+
+        # Criando a propriedade "uniques" na classe "cls", se necessário
+        self._check_class_attribute(cls, "uniques", {})
+
+        # Criando a propriedade "candidate_keys" na classe "cls", se necessário
+        self._check_class_attribute(cls, "candidate_keys", [])
 
         # Iterating for the class attributes
         for key, attr in cls.__dict__.items():
             # Test if the attribute uses the DTOFiel descriptor
             if isinstance(attr, DTOField):
                 # Storing field in fields_map
-                getattr(cls, 'fields_map')[key] = attr
+                getattr(cls, "fields_map")[key] = attr
 
                 # Setting a better name to storage_name
                 attr.storage_name = f"{key}"
+                attr.name = f"{key}"
 
                 # Checking filters name
                 self._check_filters(cls, key, attr)
@@ -55,30 +75,45 @@ class DTO:
 
                 # Checking if it is a resume field (to store)
                 if attr.resume:
-                    resume_fields = getattr(cls, 'resume_fields')
+                    resume_fields = getattr(cls, "resume_fields")
                     if not (key in resume_fields):
                         resume_fields.add(key)
 
                 # TODO Refatorar para suportar PKs compostas
                 # Setting PK info
                 if attr.pk:
-                    setattr(cls, 'pk_field', f"{key}")
+                    setattr(cls, "pk_field", f"{key}")
 
                 # Verifica se é um campo de particionamento, e o guarda em caso positivo
                 if attr.partition_data:
-                    partition_fields = getattr(cls, 'partition_fields')
+                    partition_fields = getattr(cls, "partition_fields")
                     if not (key in partition_fields):
                         partition_fields.add(key)
 
+                # Verifica se é um campo pertencente a uma unique, a populando o dicionário de uniques
+                if attr.unique:
+                    uniques = getattr(cls, "uniques")
+                    fields_unique = uniques.setdefault(attr.unique, set())
+                    fields_unique.add(key)
+
+                # Verifica se é uma chave candidata
+                if attr.candidate_key:
+                    getattr(cls, "candidate_keys").append(key)
+
             elif isinstance(attr, DTOListField):
                 # Storing field in fields_map
-                getattr(cls, 'list_fields_map')[key] = attr
+                getattr(cls, "list_fields_map")[key] = attr
 
                 # Setting a better name to storage_name
                 attr.storage_name = f"{key}"
+                attr.name = f"{key}"
 
         # Setting fixed filters
-        setattr(cls, 'fixed_filters', self._fixed_filters)
+        setattr(cls, "fixed_filters", self._fixed_filters)
+
+        # Setting tipo de Conjunto
+        setattr(cls, "conjunto_type", self._conjunto_type)
+        setattr(cls, "conjunto_field", self._conjunto_field)
 
         return cls
 
@@ -92,7 +127,6 @@ class DTO:
 
         # Handling each filter
         for filter in dto_field.filters:
-
             # Resolving filter name
             filter_name = field_name
             if filter.name is not None:
@@ -102,7 +136,7 @@ class DTO:
             filter.field_name = field_name
 
             # Adding into field filters map
-            field_filters_map = getattr(cls, 'field_filters_map')
+            field_filters_map = getattr(cls, "field_filters_map")
             field_filters_map[filter_name] = filter
 
     def _check_class_attribute(self, cls: object, attr_name: str, default_value: Any):
