@@ -16,7 +16,6 @@ DATABASE_DRIVER = os.getenv('DATABASE_DRIVER', 'POSTGRES')
 CLOUD_SQL_CONN_NAME = os.getenv('CLOUD_SQL_CONN_NAME', '')
 ENV = os.getenv('ENV', '')
 
-
 def get_logger():
-    APP_NAME = os.getenv('APP_NAME', 'nsj_multi_database_lib')
-    return logging.getLogger(APP_NAME)
+    APP_NAME = os.getenv('APP_NAME', 'nsj_rest_lib')
+    return logging.getLogger(APP_NAME)
\ No newline at end of file
